'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.convertToReactInlineStyle = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _htmlTag = require('html-tag');

var _htmlTag2 = _interopRequireDefault(_htmlTag);

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _immutableObjectMethods = require('immutable-object-methods');

var _formatHtml = require('./format-html');

var _formatHtml2 = _interopRequireDefault(_formatHtml);

var _renderCss = require('./render-css');

var _renderCss2 = _interopRequireDefault(_renderCss);

var _renderTag = require('./render-tag');

var _renderTag2 = _interopRequireDefault(_renderTag);

var _renderMeta = require('./render-meta');

var _renderMeta2 = _interopRequireDefault(_renderMeta);

var _renderAnalytics = require('./render-analytics');

var _renderAnalytics2 = _interopRequireDefault(_renderAnalytics);

var _componentToHtmlTag = require('./component-to-html-tag');

var _componentToHtmlTag2 = _interopRequireDefault(_componentToHtmlTag);

var _cssExtractor = require('./css-extractor');

var _cssExtractor2 = _interopRequireDefault(_cssExtractor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var ampElementScriptsMap = {
	video: '<script async custom-element="amp-video" src="https://cdn.ampproject.org/v0/amp-video-0.1.js"></script>',
	analytics: '<script async custom-element="amp-analytics" src="https://cdn.ampproject.org/v0/amp-analytics-0.1.js"></script>',
	'amp-story-auto-ads': '<script async custom-element="amp-story-auto-ads" src="https://cdn.ampproject.org/v0/amp-story-auto-ads-0.1.js"></script>'
};

var renderAmpElementScripts = function renderAmpElementScripts(elementsMap) {
	return Object.keys(elementsMap).map(function (element) {
		return ampElementScriptsMap[element];
	}).join('\n');
};

var textComponents = Object.keys(_componentToHtmlTag.textComponentToHtmlTagMap);

exports.default = function (_ref) {
	var title = _ref.title,
	    _ref$defaultStyles = _ref.defaultStyles,
	    defaultStyles = _ref$defaultStyles === undefined ? {} : _ref$defaultStyles,
	    _ref$pages = _ref.pages,
	    pages = _ref$pages === undefined ? [] : _ref$pages,
	    canonicalUrl = _ref.canonicalUrl,
	    meta = _ref.meta,
	    _ref$customCss = _ref.customCss,
	    customCss = _ref$customCss === undefined ? '' : _ref$customCss,
	    _ref$analytics = _ref.analytics,
	    analytics = _ref$analytics === undefined ? [] : _ref$analytics,
	    bookendConfigSrc = _ref.bookendConfigSrc,
	    preview = _ref.preview,
	    autoAdsConfig = _ref.autoAdsConfig;

	(0, _assert2.default)(title, '.title is required');
	(0, _assert2.default)(canonicalUrl, '.canonicalUrl is required');
	(0, _assert2.default)(preview, '.preview is required');
	(0, _assert2.default)(preview.publisher, '.preview.publisher is required');
	(0, _assert2.default)(preview.publisherLogoSrc, '.preview.publisherLogoSrc is required');
	(0, _assert2.default)(preview.posterPortraitSrc, '.preview.posterPortraitSrc is required');

	console.log('bookendConfigSrc', bookendConfigSrc);
	var ampElementsThatNeedScripts = {};

	if (analytics.length > 0) {
		ampElementsThatNeedScripts.analytics = true;
	}

	if (autoAdsConfig) {
		ampElementsThatNeedScripts['amp-story-auto-ads'] = true;
	}

	var _createCssExtractor = (0, _cssExtractor2.default)(),
	    appendStyles = _createCssExtractor.appendStyles,
	    getCombinedCss = _createCssExtractor.getCombinedCss;

	var renderTag = (0, _renderTag2.default)(appendStyles);

	var renderTextElement = function renderTextElement(tagName) {
		return function (_ref2) {
			var text = _ref2.text,
			    props = _objectWithoutProperties(_ref2, ['text']);

			// Special case for inline text elements, we wrap them into
			// another div to revert to non-flex behavior. The only purpose of inline
			// is to support wrapping text background.
			if (props.styles && props.styles.display === 'inline') {
				return renderTag('div', { styles: { display: 'inline' } }, renderTag(tagName, props, text));
			}

			return renderTag(tagName, props, text);
		};
	};

	var elementTypeToRenderMap = _extends({}, textComponents.reduce(function (accum, componentName) {
		return _extends({}, accum, _defineProperty({}, componentName, renderTextElement(_componentToHtmlTag.textComponentToHtmlTagMap[componentName])));
	}, {}), {
		container: function container(_ref3) {
			var _ref3$elements = _ref3.elements,
			    elements = _ref3$elements === undefined ? [] : _ref3$elements,
			    props = _objectWithoutProperties(_ref3, ['elements']);

			return renderTag(_componentToHtmlTag2.default.container, props, elements.map(function (element) {
				return renderElement(element);
			}).join('') // eslint-disable-line no-use-before-define
			);
		},
		image: function image(props) {
			return renderTag(_componentToHtmlTag2.default.image, _extends({}, props));
		},
		video: function video(_ref4) {
			var sources = _ref4.sources,
			    props = _objectWithoutProperties(_ref4, ['sources']);

			ampElementsThatNeedScripts.video = true;

			return renderTag(_componentToHtmlTag2.default.video, props, sources.map(function (_ref5) {
				var source = _ref5.source,
				    type = _ref5.type;
				return renderTag('source', {
					source: source,
					type: type.split('/').length === 1 ? 'video/' + type : type
				});
			}).join(''));
		}
	});

	var renderElement = function renderElement(_ref6) {
		var type = _ref6.type,
		    layer = _objectWithoutProperties(_ref6, ['type']);

		return elementTypeToRenderMap[type](layer);
	};

	var renderLayer = function renderLayer(element) {
		return renderTag('amp-story-grid-layer', { template: element.template ? element.template : 'vertical' }, renderTag('div', {}, renderTag('div', {
			styles: {
				left: 0,
				top: 0,
				width: '100%',
				height: '100%',
				position: 'absolute',
				display: 'flex'
			}
		},
		// Add "flex: 1" to all top level elements
		renderElement((0, _immutableObjectMethods.mergeDeep)({ styles: { flex: 1 } }, element)))));
	};

	var renderPage = function renderPage(_ref7, index) {
		var id = _ref7.id,
		    autoAdvanceAfter = _ref7.autoAdvanceAfter,
		    layers = _ref7.layers;
		return renderTag('amp-story-page', {
			id: id || 'page-' + index,
			'auto-advance-after': typeof autoAdvanceAfter === 'number' ? autoAdvanceAfter + 's' : autoAdvanceAfter
		}, layers.map(renderLayer).join(''));
	};

	var renderStory = function renderStory(storyPages, storyAnalytics) {
		return renderTag('amp-story', {
			standalone: true,
			title: title,
			publisher: preview.publisher,
			'publisher-logo-src': preview.publisherLogoSrc,
			'poster-portrait-src': preview.posterPortraitSrc,
			'poster-square-src': preview.posterSquareSrc,
			'poster-landscape-src': preview.posterLandscapeSrc
		}, [autoAdsConfig && renderTag('amp-story-auto-ads', {}, (0, _htmlTag2.default)('script', { type: 'application/json' }, JSON.stringify(autoAdsConfig))), (0, _renderAnalytics2.default)(storyAnalytics)].concat(_toConsumableArray(storyPages.map(renderPage)), [bookendConfigSrc && renderTag('amp-story-bookend', {
			layout: 'nodisplay'
		}, (0, _htmlTag2.default)('script', { type: 'application/json' }, JSON.stringify(bookendConfigSrc)))]).filter(Boolean).join(''));
	};
	// This has to happen first so that acmpElementsThatNeedScripts will be filled
	var renderedStory = renderStory(pages, analytics);
	var seoTitle = meta.jsonld.name || title;

	return (0, _formatHtml2.default)('<!doctype html>\n  <html \u26A1 lang="en">\n    <head>\n      <meta charset="utf-8">\n      <script async src="https://cdn.ampproject.org/v0.js"></script>\n      <script async custom-element="amp-story" src="https://cdn.ampproject.org/v0/amp-story-1.0.js"></script>\n      ' + renderAmpElementScripts(ampElementsThatNeedScripts) + '\n      <title>' + seoTitle + '</title>\n      <link rel="canonical" href="' + canonicalUrl + '" />      \n      <meta name="viewport" content="width=device-width,minimum-scale=1,initial-scale=1">\n      ' + _formatHtml.ampStyleBoilerplatePlaceholder + '\n      <style amp-custom>\n        .img-cover img{object-fit: cover}        \n        ' + customCss + (0, _renderCss2.default)(_extends({}, defaultStyles, getCombinedCss())) + '\n      </style>\n      ' + (typeof meta === 'string' ? meta : (0, _renderMeta2.default)(_extends({
		title: title,
		canonicalUrl: canonicalUrl
	}, meta))) + '\n    </head>\n    <body>\n      ' + renderedStory + '\n    </body>\n  </html>');
};

var convertToReactInlineStyle = exports.convertToReactInlineStyle = _renderCss.convertToReactInlineStyle;