'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertToReactInlineStyle = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _postcssJs = require('postcss-js');

var _postcssJs2 = _interopRequireDefault(_postcssJs);

var _autoprefixer = require('autoprefixer');

var _autoprefixer2 = _interopRequireDefault(_autoprefixer);

var _dasherize = require('dasherize');

var _dasherize2 = _interopRequireDefault(_dasherize);

var _immutableObjectMethods = require('immutable-object-methods');

var _lodash = require('lodash.flow');

var _lodash2 = _interopRequireDefault(_lodash);

var _componentToHtmlTag = require('./component-to-html-tag');

var _componentToHtmlTag2 = _interopRequireDefault(_componentToHtmlTag);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var convertToPx = function convertToPx(value) {
  return value + 'px';
};
var convertDistance = function convertDistance(distance) {
  return typeof distance === 'number' ? convertToPx(distance) : distance;
};

var convertBackgroundLinearGradient = function convertBackgroundLinearGradient(styles) {
  var backgroundLinearGradient = styles.backgroundLinearGradient;


  if (!backgroundLinearGradient) {
    return styles;
  }

  var direction = backgroundLinearGradient.direction,
      stops = backgroundLinearGradient.stops;


  var gradientString = [direction].concat(_toConsumableArray(stops.map(function (_ref) {
    var color = _ref.color,
        distance = _ref.distance;
    return [color, convertDistance(distance)].filter(Boolean).join(' ');
  }))).join(', ');

  return (0, _immutableObjectMethods.chain)(styles).set('background', 'linear-gradient(' + gradientString + ')').without('backgroundLinearGradient').value;
};

var convertFlexProperties = function convertFlexProperties(styles) {
  var justifyContent = styles.justifyContent,
      alignItems = styles.alignItems;


  if (!justifyContent && !alignItems) {
    return styles;
  }

  var stylesToReturn = _extends({}, styles);
  if (justifyContent) {
    stylesToReturn = (0, _immutableObjectMethods.set)(stylesToReturn, 'alignContent', justifyContent);
  }
  if (alignItems) {
    stylesToReturn = (0, _immutableObjectMethods.set)(stylesToReturn, 'justifyItems', alignItems);
  }

  return stylesToReturn;
};

var overrideGridGap = function overrideGridGap(styles) {
  return (0, _immutableObjectMethods.set)(styles, 'gridGap', 0);
};

var converters = [convertBackgroundLinearGradient, convertFlexProperties, overrideGridGap];

var convertTransforms = function convertTransforms(array) {
  return array.map(function (object) {
    var key = Object.keys(object)[0];
    var value = object[key];
    var convertedValue = typeof value === 'number' && !key.includes('scale') ? convertToPx(value) : value;

    return key + '(' + convertedValue + ')';
  }).join(' ');
};

var convertFilters = function convertFilters(array) {
  return array.map(function (object) {
    var key = Object.keys(object)[0];
    var value = object[key];
    var convertedValue = convertDistance(value);

    return (0, _dasherize2.default)(key) + '(' + convertedValue + ')';
  }).join(' ');
};

var convertShadow = function convertShadow(value) {
  return (Array.isArray(value) ? value : [value]).map(function (_ref2) {
    var _ref2$offset = _ref2.offset,
        x = _ref2$offset.x,
        y = _ref2$offset.y,
        color = _ref2.color,
        blurRadius = _ref2.blurRadius,
        spread = _ref2.spread;
    return [convertToPx(x), convertToPx(y), typeof blurRadius !== 'undefined' && convertToPx(blurRadius), typeof spread !== 'undefined' && convertToPx(spread), color].filter(Boolean).join(' ');
  }).join(', ');
};

var convertBorder = function convertBorder(_ref3) {
  var width = _ref3.width,
      style = _ref3.style,
      color = _ref3.color;
  return [convertToPx(width), style, color].join(' ');
};

var stylePropertyToCss = {
  top: convertDistance,
  left: convertDistance,
  bottom: convertDistance,
  right: convertDistance,

  width: convertDistance,
  height: convertDistance,

  margin: convertDistance,
  marginTop: convertDistance,
  marginBottom: convertDistance,
  marginRight: convertDistance,
  marginLeft: convertDistance,

  padding: convertDistance,
  paddingTop: convertDistance,
  paddingBottom: convertDistance,
  paddingRight: convertDistance,
  paddingLeft: convertDistance,

  fontSize: convertToPx,

  border: convertBorder,
  borderTop: convertBorder,
  borderBottom: convertBorder,
  borderRight: convertBorder,
  borderLeft: convertBorder,

  borderRadius: convertToPx,
  borderTopLeftRadius: convertToPx,
  borderTopRightRadius: convertToPx,
  borderBottomLeftRadius: convertToPx,
  borderBottomRightRadius: convertToPx,

  transform: convertTransforms,
  filter: convertFilters,
  backdropFilter: convertFilters,
  boxShadow: convertShadow,
  textShadow: convertShadow
};

var convertCSS = function convertCSS(css) {
  return (0, _postcss2.default)([_autoprefixer2.default]).process(css, { parser: _postcssJs2.default }).css;
};
var convertCSSInline = _postcssJs2.default.sync([]);

var convertToReactInlineStyle = exports.convertToReactInlineStyle = function convertToReactInlineStyle() {
  var styles = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  var convertedStyle = (0, _lodash2.default)(converters)(Object.keys(styles).reduce(function (accumulator, style) {
    var propertyConverter = stylePropertyToCss[style];
    var styleValue = styles[style];

    return _extends({}, accumulator, _defineProperty({}, style, propertyConverter ? propertyConverter(styleValue) : styleValue));
  }, {}));

  return convertCSSInline(convertedStyle);
};

var parseStyles = function parseStyles(styles) {
  return Object.keys(styles).reduce(function (accumulator, elementType) {
    return _extends({}, accumulator, _defineProperty({}, _componentToHtmlTag2.default[elementType] || elementType, convertToReactInlineStyle(styles[elementType])));
  }, {});
};

exports.default = function (styles) {
  return convertCSS(parseStyles(styles));
};