'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
var TRELL_DESCRIPTION = 'Share and Spill the secrets of your travel stories and local adventuresto create a beautiful collection of your delicious food blogs and travelogues. Inspire newbies to follow your trails along with your hidden gems and exciting explorations by giving your blog a visual twist and evolving into Google search answers. | Trell.co';

function getMetaTags(storyMeta) {
	console.log('getMetaTags -> storyMeta', storyMeta);
	var title = storyMeta.title,
	    _storyMeta$author = storyMeta.author,
	    author = _storyMeta$author === undefined ? 'Trell' : _storyMeta$author,
	    _storyMeta$images = storyMeta.images,
	    images = _storyMeta$images === undefined ? [] : _storyMeta$images,
	    canonicalUrl = storyMeta.canonicalUrl,
	    _storyMeta$isNsfw = storyMeta.isNsfw,
	    isNsfw = _storyMeta$isNsfw === undefined ? false : _storyMeta$isNsfw,
	    jsonld = storyMeta.jsonld;
	var name = jsonld.name,
	    description = jsonld.description;


	if (!images[0]) {
		console.error('images array in meta obj should contain at least one source');
	}

	return '\n    <meta name="description" content="' + description + '">\n\n    <meta name="robots" content="' + (isNsfw ? 'noindex' : 'max-video-preview:-1, index, follow') + '" />\n\n\n    <meta property="og:title" content="' + name + '" />\n    <meta property="og:type" content="article" />\n    <meta property="og:url" content="' + canonicalUrl + '" />\n    <meta property="og:image" content="' + (images[0] || '') + '" />\n    <meta property="og:site_name" content="Trell" />\n\n    <meta name="twitter:card" content="summary_large_image">\n    <meta name="twitter:site" content="@TrellApp">\n    <meta name="twitter:creator" content="@TrellApp">\n    <meta name="twitter:title" content="' + name + '">\n    <meta name="twitter:description" content="' + description + '">\n    <meta name="twitter:image" content="' + (images[0] || '') + '">\n\n    <link rel="shortcut icon" href="https://amp.trell.co/favicon.ico">\n  ';
}

exports.default = function (storyMeta) {
	var schemaType = storyMeta.schemaType,
	    jsonld = storyMeta.jsonld;


	if (!jsonld) {
		throw new Error('Invalid schema type ' + schemaType + ',  Valid schema types are VIDEO and NEWS');
	}

	return '\n  ' + getMetaTags(storyMeta) + '\n  <script type="application/ld+json">\n  ' + JSON.stringify(jsonld) + '\n  </script>';
};

function newsArticleMeta(storyMeta) {
	var title = storyMeta.title,
	    canonicalUrl = storyMeta.canonicalUrl,
	    images = storyMeta.images,
	    datePublished = storyMeta.datePublished,
	    dateModified = storyMeta.dateModified,
	    author = storyMeta.author,
	    publisher = storyMeta.publisher,
	    description = storyMeta.description;


	var json = {
		'@context': 'http://schema.org',
		'@type': 'NewsArticle',
		headline: title,
		description: description,
		image: images && images.length && images,
		datePublished: datePublished,
		dateModified: dateModified,
		publisher: publisher,
		author: author && {
			'@type': 'Person',
			name: author
		},
		mainEntityOfPage: {
			'@type': 'WebPage',
			'@id': canonicalUrl
		}
	};

	return json;
}

function videoObjectMeta(storyMeta) {
	var title = storyMeta.title,
	    _storyMeta$images2 = storyMeta.images,
	    images = _storyMeta$images2 === undefined ? [] : _storyMeta$images2,
	    _storyMeta$author2 = storyMeta.author,
	    authorName = _storyMeta$author2.name,
	    authorHandle = _storyMeta$author2.handle,
	    profileLink = _storyMeta$author2.profileLink,
	    publisher = storyMeta.publisher,
	    description = storyMeta.description,
	    comment = storyMeta.comment,
	    videoUrl = storyMeta.videoUrl,
	    canonicalUrl = storyMeta.canonicalUrl,
	    ISO8601Duration = storyMeta.ISO8601Duration,
	    ISO8601Publish = storyMeta.ISO8601Publish,
	    _storyMeta$videoStats = storyMeta.videoStats,
	    loves = _storyMeta$videoStats.loves,
	    views = _storyMeta$videoStats.views,
	    comments = _storyMeta$videoStats.comments;

	// verify if properties exist

	var json = {
		'@context': 'https://schema.org',
		'@type': 'VideoObject',
		name: title,
		description: description,
		thumbnailUrl: images,
		uploadDate: ISO8601Publish, // ISO 8601
		duration: ISO8601Duration, // ISO 8601
		contentUrl: videoUrl,
		embedUrl: videoUrl, // should this be different than contentURL
		interactionStatistic: [{
			'@type': 'InteractionCounter',
			interactionType: { '@type': 'http://schema.org/WatchAction' },
			userInteractionCount: views
		}, {
			'@type': 'InteractionCounter',
			interactionType: { '@type': 'http://schema.org/LikeAction' },
			userInteractionCount: loves
		}],
		publisher: publisher,
		creator: {
			'@type': 'Person',
			name: authorName,
			url: profileLink,
			alternateName: authorHandle
		},
		commentCount: comments,
		comment: comment,
		mainEntityOfPage: {
			'@type': 'WebPage',
			'@id': canonicalUrl
		}
	};

	return json;
}